import unittest
import requests
import ujson
from Crypto.Hash import MD5
import dg_sdk
from tests.conftest import *


class TestDGApi(unittest.TestCase):

    def setUp(self):
        huifu_id1 = "6666000120254152"
        sys_id1 = "6666000120254152"
        product_id = "YYZY"
        private_key1 = "MIIEvgIBADANBgkqhkiG9w0BAQEFAASCBKgwggSkAgEAAoIBAQDZBr2JmycRODc2KwyejpG+6GE0ww3V+2hoEY7zfHtzVVLJy0P2XfcFngTXLXS9q/5GF6KTgANXfZlHpx1dzDA7ZQg2edIFdPYccmjJMPVlUT1tpmPgMb30DPy/Shte19+ZK2eWlBGXPkUVHxbD+5dKjqSZijdil9caZqPMEeOwcXDMXCQvDlkolqVVTTY/Ph/Za/cQGbjqy8OCpkwxCfWHJ9Ij6w/FatZ8rjzibLTRow3vERC88BNYBJQmdEeCMnGHGdssgX8QbJVSMgDfkhBKFSKNPOXQBQkzAV0nJJZ8wUGDH38fHIESl0u5UKtVloHBfx4s4f6co1Im6a3yl+WBAgMBAAECggEBAKkP/CSvDb73SONUo878hwLt6ZN9g1C3OX0geHiq90xAIm76fmX0ixMAJwss6O08h6c4kDhRF8lXGUndIB5KiyQprz0opvgDRhmg8ooQLooPwEejv9gNR8lPOLEXXL0Ec7XRPy/pBs8H/i7W+hgP7Kpy9jx5lG2klTeGz4CQSwvN06mkZN9XlUj4gJ2egt9lvFTKaKGSsgBuxaxpJdhaDHSccS7JmLme5fDBG8FZpHbep8yLkmdtxrCYdtYa4KoTmjpWlsi3jYLaO/Y5aHNBrS/tv8dzrdPbcXjyg1o6+caebogwdxSr4WtH1dvq8cj8Wn8uY/pv07Cl5YdQwTOGjLUCgYEA9RVWDUioTw/fD3zl/n5L2/ujPVnH/+ADWHzfgc5si7O2BqyXsIdFxK0TkAT/8ZwUtGWEAf4S6LEjU7b3vjbz+4+RK4+PVfXmie1cEbHgNlW/fDKuPLQ0k/CjugI/0d26xqs5YzCXoA1nNiMOLOxyNa9Wf0sxEKYF+/vE22taXn8CgYEA4rF4+gsgc5Yu9ILyfDSn0A0bMzst1kAWST1aG3SaIUJiL54VQtrr+50sli1xTndqH1WOC7Jh14lQcZvcPLq1KkPPD/u00XwqTAmFi4yTllef/V4YWsGJ6zsilMtQlmuqtKLckgPbAsV39wpdM7OZkQGU5pVVNzDy+0qjSbLzu/8CgYB8ldsHp66/eh73PZOhGkyvyCyETHaJ0TOCMQBheTDel31pySTXPPyvbRgrtw7woFo6FfzUEndESH/f13v6+u5uK94tGa5QkU8fQET0TcrfdBmCJjVCcIzlw4dHUEtnAOMoiPQEQzhgyU91Sr6zAYNRXQ+IaA3KG8ug+6xnqhvnOwKBgHa6JHYw5aoj+iuteXp7yXg5pQlL8VHI9uMc8th2VVMeBXaTAOem6Pk69GMjIbjK6hXHJUITBxNvo2YdD1fvIXslUIk6dxVQRobUZdEUqyeOdQiqA29k9erxaccsROTDNwCsW4FN66Kj8ZS9JNszMTa08Vti0uK5DEl4adTrmKPZAoGBAIu7DRxSv8dUFljN7ynJKkDDy2h7UdiwOSRcGF/vQmdN17+WR8Eiqiyfc7cNyMNMIOlrmYi6ISYF1UhjJ1SPGoCr6p+84vzl8pQgpZU5mjaLZABzC0mtwEyqDidqDqjkiSdkggrTZJsHR2gn1c8GSxIa5lkVA0K4BZr8cBOA2Xks"
        public_key1 = "MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAtNUaxFyNguNGUQ8fSwfnL4UPAlsPMvG8Fv3iZ41hQgBFsgF+ScVXPLBb5+E0PB22UvSev0DYG+wVhbbkDScGkNDvW2nGpgKO4X3TK7XuhbkExB892zI05fTG/zURvEiLbQ/u6d9yvuF13ouayZwsNTqTY2CTn0o2YXw2MsdEW91FP4SUn6XFacqCfxPvBvjmOg3Mj9k7TzU7Q0O/gMvFqY02LEjxwwBa/rbWMaPwJRz9XWBWnkL4x4lo5iWF/PFaTm9Ifr2XsxjXycZCd9nNQ1MEi4PqW2YBqmALhR883C7eVAQAjBBLqCdZ6tjLYfa+4qcjtJMs9w3VtLzIdVAbHQIDAQAB"
        dg_sdk.DGClient.mer_config = dg_sdk.MerConfig(private_key1, public_key1, sys_id1, product_id, huifu_id1)
        print("setup")

    def tearDown(self):
        print("tearDown")

    # 企业商户进件
    def test_create_enterprise(self):
        merchant_info = dg_sdk.MerchantInfo(short_name="yong",
                                            prov_id="310000",
                                            area_id="310100",
                                            district_id="310151",
                                            detail_addr="上海-上海市-崇明区长江农场长江大街161号上海长江经济园",
                                            contact_name="yingyongwang",
                                            contact_mobile_no="17602151526",
                                            contact_email="yingyong.wang@huifu.com",
                                            busi_type="1",
                                            receipt_name="will超市",
                                            mcc="5311",
                                            service_phone="17602151526",
                                            sms_send_flag="Y",
                                            login_name="willwang1")

        card_info = dg_sdk.MerCardInfo(card_type="2",
                                       card_name="王英永",
                                       card_no="6214852106586327",
                                       prov_id="310000",
                                       area_id="310100",
                                       bank_code="03080000",
                                       branch_name="",
                                       cert_type="00",
                                       cert_no="370481198704223510",
                                       cert_validity_type="0",
                                       cert_begin_date="20181201",
                                       cert_end_date="20281201",
                                       mp="")
        lic_info = dg_sdk.BussinessLicInfo(reg_name="上海汇涵信息科技服务有限公司",
                                           ent_type="3",
                                           license_code="91310230MA1JTWAK98",
                                           reg_prov_id="310000",
                                           reg_area_id="310100",
                                           reg_district_id="310151",
                                           reg_detail="上海-上海市-崇明区长江农场长江大街161号上海长江经济园",
                                           license_validity_type="1",
                                           license_begin_date="20190705",
                                           license_end_date="")

        legal_info = dg_sdk.LegalInfo(legal_name="张戈",
                                      legal_cert_type="00",
                                      legal_cert_no="510102196609237493",
                                      legal_cert_validity_type="0",
                                      legal_cert_begin_date="20050813",
                                      legal_cert_end_date="20250813")
        settle_info = dg_sdk.SettleConfigInfo(settle_cycle="D1",
                                              min_amt="1.00",
                                              remained_amt="2.00",
                                              settle_abstract="abstract",
                                              out_settle_flag="2",
                                              out_settle_huifuid="",
                                              fixed_ratio="5.00")
        cash_config = dg_sdk.CashConfigInfo(cash_type="D0",
                                            fix_amt="1.00",
                                            fee_rate="0.11")
        cash_list = [cash_config]

        result = dg_sdk.Merchant.create_enterprise(upper_huifu_id=upper_huifu_id,
                                                   merch_info=merchant_info,
                                                   card_info=card_info,
                                                   lic_info=lic_info,
                                                   legal_person=legal_info,
                                                   )

        assert result["resp_code"] == "00000001"

    def test_query_ent(self):
        result = dg_sdk.Merchant.query_merch_info(huifu_id="6666000120254152")
        assert result["resp_code"] == "00000000"

    def test_query_apply_no(self):
        result = dg_sdk.Merchant.query_apply_status(apply_no="2022072200769029")
        assert result["resp_code"] == "00000000"

    def test_open(self):
        sys_id1 = "6666000108840829"
        alipay = {
            "mcc": "2015050700000000",
            "pay_scene": "1",
            "fee_rate": "0.81",
        }
        ali_conf_list = [alipay]
        result = dg_sdk.Merchant.reg_busi_info(upper_huifu_id=sys_id1, ali_conf_list=json.dumps(ali_conf_list))
        assert result["resp_code"] == "00000000"

    def test_payment_create(self):
        result = dg_sdk.ScanPayment.create(trade_type="A_NATIVE", trans_amt="0.01", goods_desc="test",
                                           notify_url="https://checkoutbfftest.cloudpnr.com/v1/callback")
        assert result["resp_code"] == "00000000"

    def test_payment_query(self):
        # "req_date": "20220726", "req_seq_id": "202207261659088430969""https://qr.alipay.com/bax07930dlbbhmobf2ei0013"
        result = dg_sdk.ScanPayment.query(org_req_date="20220726", org_req_seq_id="202207261659088430969")
        assert result["resp_code"] == "00000000"

    def test_refund(self):
        # "req_date":"20220726","req_seq_id":"202207261703353473238"
        result = dg_sdk.ScanPayment.refund(ord_amt="0.01", org_req_date="20220726",
                                           org_req_seq_id="202207261710496301903")
        assert result["resp_code"] == "00000000"

    def test_refund_query(self):
        result = dg_sdk.ScanPayment.refund_query(org_req_date="20220726", org_req_seq_id="202207261703353473238")
        assert result["resp_code"] == "00000000"

    def test_upload(self):
        result = dg_sdk.Merchant.upload(file_type="F17", picture_path="../test_pic.png")
        assert result["data"]["resp_code"] == "00000000"


def helipay_sign(params: dict):
    # E1807227095
    orginal_str = ""
    for key in params.keys():
        orginal_str += "&" + params[key]
    orginal_str += "&u9TuVGfn3hOFTuhBwRgomvugKmM9hyM5"
    print(orginal_str)
    h = MD5.new()
    h.update(str(orginal_str).encode('utf-8'))
    sign = h.hexdigest().lower()
    print(sign)
    return sign


def helipay_request(params):
    url = "http://pay.trx.helipay.com/trx/app/interface.action"
    sign = helipay_sign(params)
    params["sign"] = sign
    response = requests.post(url, params=params, verify=False)  # 发送请求
    if response.status_code != 200:
        try:
            reason = json.loads(response.text)['message']
        except Exception as e:
            str(e)
            reason = 'System Error'
        raise ConnectionError(response.status_code, reason)
    return ujson.loads(response.text)


class TestHELIPayApi(unittest.TestCase):

    def setUp(self):
        print("setup")

    def tearDown(self):
        print("tearDown")

    # 交易接口
    def test_payment_create(self):
        params = {
            "P1_bizType": "AppPay",
            "P2_orderId": "2022072715021",
            "P3_customerNumber": "E1807227095",
            "P4_payType": "SWIPE",
            "P5_orderAmount": "0.11",
            "P6_currency": "CNY",
            "P7_authcode": "284677387843274569",
            "P8_appType": 'ALIPAY',
            "P9_notifyUrl": "https://checkoutbfftest.cloudpnr.com/v1/callback",
            "P10_successToUrl":"",
            "P11_orderIp": "192.168.10.1",
            "P12_goodsName": 'Iphone7',
            "P13_goodsDetail":"111",
            "P14_desc": "22222",
        }
        result = helipay_request(params)
        print(result)
        assert result["rt2_retCode"] == "0000"

    def test_payment_query(self):
        params = {
            "P1_bizType": "AppPayQuery",
            "P2_orderId": "2022072715021",
            "P3_customerNumber": "E1807227095",
        }
        result = helipay_request(params)
        print(result)
        assert result["rt2_retCode"] == "0000"

    def test_payment_refund(self):
        params = {
            "P1_bizType": "AppPayRefund",
            "P2_orderId": "2022072715021",
            "P3_customerNumber": "E1807227095",
            "P4_refundOrderId":"2022072715011",
            "P5_amount":"0.11",
            "P6_callbackUrl":"https://checkoutbfftest.cloudpnr.com/v1/callback"
        }
        result = helipay_request(params)
        print(result)
        assert result["rt2_retCode"] == "0000"

    def test_payment_refund_query(self):
        params = {
            "P1_bizType": "AppPayRefundQuery",
            "P2_refundOrderId": "2022072715011",
            "P3_customerNumber": "E1807227095",
        }
        result = helipay_request(params)
        print(result)
        assert result["rt2_retCode"] == "0000"


import unittest
from tests.conftest import *


class TestTerminal(unittest.TestCase):

    def setUp(self):
        print("setup")

    def tearDown(self):
        print("tearDown")

    def test_terminal_add(self):
        terminal_info_list = [{
            "sn": "sn1",
            "tusn": "tusn",
            "dev_model_code": "01"
        }]
        result = dg_sdk.Terminal.add(terminal_info_list=json.dumps(terminal_info_list))
        assert result["resp_code"] == "00000007"

    def test_terminal_cancel(self):
        result = dg_sdk.Terminal.cancel("device_id")

        assert result["resp_code"] == "00000007"

    def test_terminal_list(self):
        result = dg_sdk.Terminal.query_list()

        assert result["resp_code"] == "00000000"



class MerCardInfo(object):
    """
    卡信息
    """
    card_type = ""
    card_name = ""
    card_no = ""
    prov_id = ""
    area_id = ""
    bank_code = ""
    branch_code = ""
    branch_name = ""
    cert_type = ""
    cert_no = ""
    cert_validity_type = ""
    cert_begin_date = ""
    cert_end_date = ""
    mp = ""

    def obj_to_dict(self):
        return {
            "card_type": self.card_type,
            "card_name": self.card_name,
            "card_no": self.card_no,
            "prov_id": self.prov_id,
            "area_id": self.area_id,
            "bank_code": self.bank_code,
            "branch_code": self.branch_code,
            "branch_name": self.branch_name,
            "cert_type": self.cert_type,
            "cert_no": self.cert_no,
            "cert_validity_type": self.cert_validity_type,
            "cert_begin_date": self.cert_begin_date,
            "cert_end_date": self.cert_end_date,
            "mp": self.mp
        }



import unittest
from tests.conftest import *


class TestDGTools(unittest.TestCase):

    def setUp(self):
        print("setup")

    def tearDown(self):
        print("tearDown")

    def test_verfy_sign(self):
        data = {"resp_desc": "业务执行失败", "req_seq_id": "202204181801142405249", "req_date": "20220418",
                "resp_code": "90000000", "huifu_id": "6666000108854952"}
        sign = "CUWBV7RUGb0cvaxvnh97giA78Z5ZWKvlQOwTpNqLjigeKZSiWmp1EgPqjMZM/UnhNcpglLHZo/DFep3X05Ycdwsyqv7PkSnN/AXpi6UofQGsaxKaWNUokKfGN5TUWDsW6H843br0WNWMdRMAD1nmKj+B5pl8+HwjEv44hXUT6P+o/kPKZAlZLhBejT46L3mjoVSoiMxLpL7HSgUn43iWgCDEfWZLN6RNkn3/t/3UXtiwimc01Bqh+GbW/no95RN4BcYkJK18BjIhsLqtNvXHXkdcczofwpfa5EfEiR7h33cuqUvGGfpGbiSrxmqzoMF4kRGx242rD2nnSZZ6bIlnog=="
        result = dg_sdk.DGTools.verify_sign(data, sign)
        assert result

    def test_webhook_verfy_sign(self):
        data = {'bank_code': '10000', 'bank_message': 'Success',
                'hf_seq_id': '002900TOP2B220511142822P984ac132ff400000', 'huifu_id': '6666000108854952',
                'qr_code': 'https://qr.alipay.com/bax04465kcijedllqhuq004b', 'req_date': '20220511',
                'req_seq_id': '202205111428211506200', 'resp_code': '00000100', 'resp_desc': '下单成功',
                'trade_type': 'A_NATIVE', 'trans_amt': '1.00', 'trans_stat': 'P'}
        sign = "dcc64089c44ea77cfde785de4cfa97ba"
        result = dg_sdk.DGTools.verify_webhook_sign(json.dumps(data, ensure_ascii=False, separators=(',', ':')),
                                                    key="test_key", sign=sign)
        assert result



import json
import random
import datetime
import requests
from rsa_util_tonglian import rsa_sign, rsa_design
from requests.adapters import HTTPAdapter
from requests.packages.urllib3.util.retry import Retry

rsa_private_key_pay = 'MIICdgIBADANBgkqhkiG9w0BAQEFAASCAmAwggJcAgEAAoGBAO0HpPUP+eHk//Ba6ZOePvoZVDpOCRtt943oeVfCTllye43bqja1jVIaebX0MgX+yPYnWIQIOJ9ubSH0R4iyY9y1/HR00qkUpfW3/0usBPt9qn7r0xtFHerhVCd4dT2rKb2Oc5IhKOg05cw/BmMFohMkFsqt0jlrUXI8zJOlLIcxAgMBAAECgYA9lt/pAYa3iK5sQOMyhUrt54j4QXCiXPeXOxHUmNuM6G9sU+itoI0hCVoYymP5JNQJCf45CH3WB3Z5/SRdQ6Uoo1cjao6cCohPLxMSfJglsZCHckPH53o25RKEza4njIgKC+yN7HAhanKymhw/yYQ6i0aXq38zFIk8djMtE7R6xQJBAP6jvNy7UhPKO5rxGFKR+MvvbO3qnYH6x0jZCGY3FlxuGfbavueOiFtMeK67FuDv683dcUKi+M48yR4kH5CfIusCQQDuS9KF6mlm3kHAiZWgVhE8VVNYGpRLCRDgAKm4InGmvk5mUv+O1yAtAFVAEHWIgD4awC7Eqf1YFrSF/It9HV9TAkEAsXiU7JJxhfFw0XAvL30lFZ1tIfReinSp6A+7VuIV552k4vNaEjC4wEjv43fpXiRZCEXJ5lOHbNXYpfUvOrBuuQJAOpow8rf8Jc0g1G3Be0XPRUwii/c1YuKe4Meo9VybIIuKkkV1Dba/9fEwBepGTURkgYWjur+nSyOCT7UUxLcVewJAPLig8dVfKpsiNwYuveEYMcFaO5xoRuiB7v+CMmvxpuuK+rrFS+d7RdmwDbnBiDV4JkTgFObUiGvB7MtS+LGfhw=='
rsa_private_key_merchant = 'MIICdwIBADANBgkqhkiG9w0BAQEFAASCAmEwggJdAgEAAoGBALRYgEbi7/r+l7z6W3AlKJYBWLSvzatWypn8cCjN0aHlLZTlFpKl1Vm4qz+m/TnjBEB46HEvOrOt+qKpTwjOL0fqSPdcT71ZsuTR9Vx/XH42w7dmlLq9VXRtWerm9VLjEloYChEUtnCSdx0A8VxgwG9qit/GZursjTFEc+Q3U+mbAgMBAAECgYALktxp8C7CIaw/kqTjQwyM5+Q3SvWnfR0+bu63ElJVkfLFae2eFqoPpSQe+cqpeDIHKIXo8ZonpXl+uTUwavmqB6YWtJizsJZrnlTsW0KZDnLk0kPCKXwQFBIYFs9AlccvbQyVdDezrqpb8DLyxrK72RA3ifUU40bXwQCf6JsgoQJBAOp74xr/v2dHsaDAY8YOODQNrNPOwVfy2w7ACRNZUYnu06gIoBMRb6boJ6eEYrUCKhguDcOUm2fLyMnDB9452yECQQDE5OMnaKBDjIM31C4k/m+pYWNcFsAS/KGo49OrqMil4G0cxKzCowgPVgfPHEQac3tQTzXNqpqRLcV0RDzCQkk7AkEAxwUZ0IuroHSYjlFdHfhpuby1qRz+u7A0P8O8sECKVaFw4llXzHdrJeY76hISWYIZymYkZpFWifXMWXuAzRycIQJBAI2HzjT0w0brCSOndKgI8TD7HVYD0HuVd4sUgYICKID8CtLEGT8ru85yU9ivg9DTtA9tcMpu2P6EvUuvBVHKHiMCQHBrMBbRg38NZ+H6eB9mAurxRUZEDjFoGImSGYheWiep13bg+6bNpXFSQjcoMEPUz/+Ws/JsgeD4nV5ZCRXb0iU='
rsa_public = 'MIGfMA0GCSqGSIb3DQEBAQUAA4GNADCBiQKBgQDYXfu4b7xgDSmEGQpQ8Sn3RzFgl5CE4gL4TbYrND4FtCYOrvbgLijkdFgIrVVWi2hUW4K0PwBsmlYhXcbR+JSmqv9zviVXZiym0lK3glJGVCN86r9EPvNTusZZPm40TOEKMVENSYaUjCxZ7JzeZDfQ4WCeQQr2xirqn6LdJjpZ5wIDAQAB'
CUSID = '55058100780004S'
app_id = '00000005'
merchant_url = 'https://syb-test.allinpay.com/vsppcusapi/merchantapi/add'
pay_url = 'https://vsp.allinpay.com/apiweb/unitorder/pay'


def sign_param(params, rsa_private):
    keys = sorted(params.keys())
    result = ''
    for key in keys:
        value = params.get(key)
        if result:
            result = result + '&' + key + '=' + value
        else:
            result = key + '=' + value
    print(result)
    flag, sign = rsa_sign(rsa_private, result)
    print(sign)
    return sign


def request_ser(params, rsa_private, url):
    sign = sign_param(params, rsa_private)
    params['sign'] = sign

    request_url = url
    session = requests.Session()
    retry = Retry(connect=3, backoff_factor=0.5)
    adapter = HTTPAdapter(max_retries=retry)
    session.mount('http://', adapter)
    session.mount('https://', adapter)
    header = {"Content-Type": "application/x-www-form-urlencoded;charset=utf-8"}

    resp = session.post(request_url, json=params, headers=header)
    print(
        'request to {}\nheader={}\nrequest_params{} \nresp is {}'.format(request_url, header, params, resp.text))
    resp.close()
    return resp


def generate_random_str():
    timestamp = str(datetime.datetime.now().strftime('%Y%m%d%H%M%S'))
    return "" + timestamp + str(random.randint(100000, 9999999))


def atest_create_merchant():
    params = {
        'orgid': '',
        'cusid': '',
        'appid': '',
        'version': '11',
        'randomstr': '',
        'merchantid': '',
        'merchantname': '',
        'shortname': '',
        'servicephone': '',
        'mccid': '',
        'comproperty': '',

    }


def atest_pay():
    params = {
        'cusid': '990440148166000',
        'appid': '00000051',
        'version': '11',
        'randomstr': generate_random_str(),
        'trxamt': '10',
        'reqsn': generate_random_str(),
        'paytype': 'W01',
        'body': 'test',
        'remark': 'remark',
        'notify_url':'https://test.allinpaygd.com/JWeb/NotifyServlet',
        'validtime': '10',
        'signtype': 'RSA'
    }
    resulut = request_ser(params, rsa_private_key_pay, pay_url)


atest_pay()



from dg_sdk.request_tools import request_post
from dg_sdk.pay.pay_api_urls import surrogate_create, drawcash_query
from dg_sdk.pay.module.bank_card import BankCard


class Surrogate(object):
    """
    代发相关接口，代发，代发交易查询
    """

    @classmethod
    def query(cls, org_req_date, *, org_req_seq_id="", org_hf_seq_id="", **kwargs):
        """
        出金交易查询
        :param org_req_date: 原机构请求日期
        :param org_req_seq_id: 原机构请求流水号
        :param org_hf_seq_id: 交易返回的全局流水号
        :param kwargs: 非必填额外参数
        :return: 返回报文
        """
        required_params = {
            "org_req_date": org_req_date,
            "org_req_seq_id": org_req_seq_id,
            "org_hf_seq_id": org_hf_seq_id,
        }

        required_params.update(kwargs)
        return request_post(drawcash_query, required_params)

    @classmethod
    def create(cls, cash_amt, bank_card_info: BankCard, into_acct_date_type, purpose_desc, **kwargs):
        """
        代发

        :param cash_amt: 交易金额
        :param bank_card_info: 银行卡信息
        :param into_acct_date_type: 到账日期类型，["t0:t0单笔","t1:t1交易","d1:d1交易","t0b:t0批量"]
        :param purpose_desc: 代发用途描述
        :param kwargs: 非必填额外参数
        :return: 返回报文
        """

        required_params = {
            "cash_amt": cash_amt,
            "bank_account_name": bank_card_info.bank_account_name,
            "bank_card_no_crypt": bank_card_info.bank_card_no_crypt,
            "bank_code": bank_card_info.bank_code,
            "card_acct_type": bank_card_info.card_acct_type,
            "province": bank_card_info.province,
            "area": bank_card_info.area,
            "purpose_desc": purpose_desc,
            "into_acct_date_type": into_acct_date_type
        }
        required_params.update(kwargs)
        return request_post(surrogate_create, required_params)



import unittest
from tests.conftest import *


class TestAcctPayment(unittest.TestCase):

    def setUp(self):
        print("setup")

    def tearDown(self):
        print("tearDown")

    def test_acct_payment_create(self):
        split_branch = "{\"acct_infos\":[{\"div_amt\":\"0.01\",\"huifu_id\":\"6666000018344461\"}]}"

        result = dg_sdk.AcctPayment.create("0.01",
                                           split_branch,
                                           risk_check_data,
                                           out_huifu_id="6666000108854952")
        assert result["resp_code"] == "22000002"

    def test_acct_payment_query(self):
        result = dg_sdk.AcctPayment.query(org_req_date="20211123",
                                          org_req_seq_id="org_req_seq_id")
        assert result["resp_code"] == "23000001"

    def test_acct_payment_refund(self):
        result = dg_sdk.AcctPayment.refund(ord_amt="0.01",
                                           org_req_date="20211123",
                                           org_req_seq_id="org_req_seq_id")
        assert result["resp_code"] == "23000001"

    def test_acct_refund_query(self):
        result = dg_sdk.AcctPayment.refund_query(org_req_date="20211123",
                                                 org_req_seq_id="org_req_seq_id")
        assert result["resp_code"] == "23000001"

    def test_balance_query(self):
        result = dg_sdk.AcctPayment.balance_query()
        assert result["resp_code"] == "00000000"



import unittest
from tests.conftest import *


class TestUniPayMerchant(unittest.TestCase):

    def setUp(self):
        print("setup")

    def tearDown(self):
        print("tearDown")

    def test_apply_register_mer(self):
        file = dg_sdk.FileInfo("F120", "file_idfile_id", "fileName")
        file2 = dg_sdk.FileInfo("F121", "file_idfile_id", "fileName")
        file_list = [file, file2]
        result = dg_sdk.UniPayMerchant.apply_register_mer(mer_type="MERCHANT_02",
                                                          legal_mobile="13122223333",
                                                          deal_type="02",
                                                          contract_id_no="3104222233222222",
                                                          file_list=file_list,
                                                          )
        assert result["sub_resp_code"] == "00000003"

    def test_query_apply_reg(self):
        result = dg_sdk.UniPayMerchant.query_apply_reg(serial_no="wk521722712574541824")
        assert result["sub_resp_code"] == "00000003"

    def test_query_mer_base_info(self):
        result = dg_sdk.UniPayMerchant.query_mer_base_info(mer_no="521722712545181696")
        assert result["sub_resp_code"] == "00000000"

    def test_query_activity_list(self):
        result = dg_sdk.UniPayMerchant.query_activity_list()
        assert result["sub_resp_code"] == "00000000"

    def test_enlist_activity(self):
        result = dg_sdk.UniPayMerchant.enlist_activity(activity_id="activity_id",
                                                       mer_no="521722712545181696")
        assert result["sub_resp_code"] == "00000003"

    def test_query_enlish_activity_status(self):
        result = dg_sdk.UniPayMerchant.query_enlish_activity_status(enlist_id="enlist_id")
        assert result["sub_resp_code"] == "00000003"



import unittest
from tests.conftest import *


class TestPos(unittest.TestCase):

    def setUp(self):
        print("setup")

    def tearDown(self):
        print("tearDown")

    def test_device_info(self):
        terminal_device_data = json.dumps({"device_id": "660035152267200170401",
                                           "client_ip": "127.0.0.1",
                                           "network": '1',
                                           "sendTime": "20220107143632"})
        result = dg_sdk.POS.query("20091225", "1",
                                  terminal_device_data,
                                  out_order_id="out_order_id")
        assert result["resp_code"] == "23000001"



import unittest

import dg_sdk
from tests.conftest import *


class TestScanPayment(unittest.TestCase):

    def setUp(self):

        huifu_id = "6666000108854952"
        sys_id = "6666000108854952"
        product_id = "YYZY"
        private_key = "MIIEvQIBADANBgkqhkiG9w0BAQEFAASCBKcwggSjAgEAAoIBAQCxtfk3rjwdpBV81WBy5jIMcDLFdvHckhjGXkmWfaBn7euPRyetEhS4inpr7EvQ5KDUXNBPljI2NVhG/LEGZKvau1MW8j3t7dJ3gWafuVGsCiLJHU79sIRHf11nKOTykX5WxB/7MMwRnZsECuaZyCk7WPuSAlznqbDJdrZTzHhjQzMhjto1qD6+vc0OxyaBFlOY9piBtEfecsvD+6GfQ8exFqwzblJm9iZPYw02DaeUDLFO9Umn7i7gShlj/1Hh8nEM7YitpF/p26o+MC9LHWbIjgzjvNVhSRVmbvWys+3S11Zm/vux6Yzfk0H3fqrksAKSEkLEtEoYKS4wKjHdecztAgMBAAECggEACy1g4WmqCks5tsJM8K0d1L5x0w2qJK9js4ZWpop8Pk0ulbJqAm6ysvCyxnr0Qc0/eFvmFjtiKRqt1LksATTvwjAqB7Vww7hDlpSi+cTUKDfy/CdFwpsJlt2h6E0gKUmRYq+vO0NUcn8xMs3ktyNpxHvSRtqzMTbxEZrP2PFxWPzUKGNyk53FTlJ64YCoGQqWeGhA5LO6QLPHlAxIrvRf9B5dtXQr5XZXVqS9MwjtsRPvQPWiFXxlzvhJRcL/wXehcNextHzpMMgX/idB3HIpIl6XXLKiFUR4rBDJIMiQjQvS6zz2l1zpiJ0vWujVa3IY+PNefRA2ttg1DeC19GYa2QKBgQDh7AkJ7wut7p4qYAdcFEDVhFgP5mnSRyOBGWmClHYE4RIFplPiv4yO0fttAjFuCg4Zaxq49BuV3zshWOEIr72VK6wMa6Z+QbfXNr/1DT6nW+ktgXTw2G9Ts/nZiMrpcsbl7qvwChfJAPvEwnyP7Ckmd9t2WbQisuYZc+Vu8znO7wKBgQDJXskTiExEipQSOcVH5cX/ExVyj9MoLjmJhy3WTTDzGafgEoOPOfej2ZCgF6gCwugXJr+rtgdOpASk8WPACaCePdjdgQ2NVhSfV3op3TtvhgAPf3iI/zCVkZM4I1iZs6KjdHstLCKyAzCFBsowkPbfZBlFX4eO7Bk6XcIZ6x2h4wKBgQDcH64C5s4bb2beZOhm2Dj/kU54V4l93+CBFjCOkXaYdG+p35DWWspqEcCHSt68l8F7FLdZxEbodTPY3w+L9iejI4UkKPN1CzVD1U2dR4VnbY85zmwRiuCVzsM/KCCE61dOi4ktfbgFGhc1dEYHuROzLo8/tlFkiajW3eyLeSM3MwKBgATL3iw57d8gEeDRQXKx9WJa+QLOjDAD0dkFwEC/e+/+Z3I93qZVsiFT+E7n4VeXfuG2SZB0eH4WCApJuZ+EWzAJtxWnkkQQjdMxyTYgD99bKLs1xRA2S9j0K7aFmQGoNrJ//sMXrwfgbZJtk/lOKqMthjCR0u/DjeJHA22MnRsTAoGADXzJs/of0JExvQWwfdIUnSEPs/PgTrrJpo+CAdXnagYHF+InrmvIcNwx6ZzIs+9aGwUt0d/YsSpJkHMfAtTwZjB7sSw8Cg5DZ179Jy3YkKhFPvZv2ZCANa5J74HZNQUrUUL6O4FouZUiLwFlq8YuUPRtkAjYwyS/jwUbhJzqZhQ="
        public_key = "MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAkMX8p3GyMw3gk6x72h20NOk3L9+Nn9mOVP6+YoBwCe7Zs4QmYrA/etFRZw2TQrSc51wgtCkJi1/x8Wl7maPL1uH2+77JFlPv7H/F4Lr2I2LXgnllg6PtwOSw/qvGYInVVB4kL85VQl0/8ObyxBUdJ43I0z/u8hJb2gwujSudOGizbeqQXAYrwcNy+e+cjodpPy9unpJjBfa4Wz2eVLLvUYYKZKdRn6pZR2cQsMBvL30K4cFlZqlJ9iP2hTG3gaiZJ9JrjTigwki0g9pbTDXiPACfuF1nOeObvLD22zBbgn1kwgfsqoG67z7g84u2jvfUFCzX1JRgd0xfNorTRkS2RQIDAQAB"

        dg_sdk.DGClient.mer_config = dg_sdk.MerConfig(private_key, public_key, sys_id, product_id, huifu_id)

        print("setup")

    def tearDown(self):
        print("tearDown")

    def test_payment_create(self):
        result = dg_sdk.ScanPayment.create(trade_type="A_NATIVE",
                                           trans_amt="1.00",
                                           goods_desc="test")
        assert result["resp_code"] == "00000100"

    def test_payment_query(self):
        result = dg_sdk.ScanPayment.create(trade_type="A_NATIVE",
                                           trans_amt="1.00",
                                           goods_desc="test")

        result = dg_sdk.ScanPayment.query(org_req_date=result["req_date"],
                                          org_req_seq_id=result["req_seq_id"])

        assert result["resp_code"] == "00000000"

    def test_payment_close(self):
        result = dg_sdk.ScanPayment.create(trade_type="A_NATIVE",
                                           trans_amt="1.00",
                                           goods_desc="test")

        result = dg_sdk.ScanPayment.close(org_req_date=result["req_date"],
                                          org_req_seq_id=result["req_seq_id"])

        assert result["resp_code"] == "20000001"

    def test_payment_close_query(self):
        result = dg_sdk.ScanPayment.create(trade_type="A_NATIVE",
                                           trans_amt="1.00",
                                           goods_desc="test")
        result = dg_sdk.ScanPayment.close(org_req_date=result["req_date"],
                                          org_req_seq_id=result["req_seq_id"])
        result = dg_sdk.ScanPayment.close_query(org_req_date=result["req_date"],
                                                org_req_seq_id=result["req_seq_id"])

        assert result["resp_code"] == "23000001"

    def test_payment_refund(self):
        result = dg_sdk.ScanPayment.create(trade_type="A_NATIVE",
                                           trans_amt="1.00",
                                           goods_desc="test")

        result = dg_sdk.ScanPayment.refund(ord_amt="0.01",
                                           org_req_date=result["req_date"],
                                           org_req_seq_id=result["req_seq_id"])

        assert result["resp_code"] == "23000000"

    def test_payment_refund_query(self):
        result = dg_sdk.ScanPayment.create(trade_type="A_NATIVE",
                                           trans_amt="1.00",
                                           goods_desc="test")

        result = dg_sdk.ScanPayment.refund(ord_amt="0.01",
                                           org_req_date=result["req_date"],
                                           org_req_seq_id=result["req_seq_id"])
        result = dg_sdk.ScanPayment.refund_query(org_req_date=result["req_date"],
                                                 org_req_seq_id=result["req_seq_id"])

        assert result["resp_code"] == "23000001"

    def test_union_user_id(self):
        result = dg_sdk.ScanPayment.union_user_id("fadsfa/tTBQ==")
        assert result["data"]["resp_code"] == "90000000"

    def test_micro_create(self):
        result = dg_sdk.ScanPayment.micro_create("0.10",
                                                 "test",
                                                 "12212312312312",
                                                 risk_check_data)
        assert result["resp_code"] == "10000000"

    def test_confirm(self):
        result = dg_sdk.ScanPayment.confirm(org_req_date="20220401",
                                            org_req_seq_id="22121212121221")
        assert result["resp_code"] == "23000001"

    def test_confirm_query(self):
        result = dg_sdk.ScanPayment.confirm_query(org_req_date="20220401",
                                                  org_req_seq_id="22121212121221")
        assert result["resp_code"] == "23000001"

    def test_confirm_refund(self):
        result = dg_sdk.ScanPayment.confirm_refund(org_req_date="20220401",
                                                   org_req_seq_id="22121212121221")
        assert result["resp_code"] == "23000001"

    def test_preorder_create1(self):
        hosting_data = {
            "project_title": "project_title",
            "project_id": "project_id",
            "private_info": "private_info",
            "callback_url": "https://paas.huifu.com/partners/api/#/cpjs/api_cpjs_hosting"
        }
        result = dg_sdk.ScanPayment.preorder_create(pre_order_type="1",
                                                    trans_amt="1.01",
                                                    goods_desc="goods_desc",
                                                    hosting_data=json.dumps(hosting_data))
        assert result["resp_code"] == "40000001"

    def test_preorder_create2(self):
        app_data = {
            "app_schema": "app_schema",
        }
        result = dg_sdk.ScanPayment.preorder_create(pre_order_type="2",
                                                    trans_amt="1.01",
                                                    goods_desc="goods_desc",
                                                    app_data=json.dumps(app_data))
        assert result["resp_code"] == "00000000"

    def test_preorder_create3(self):
        miniapp_data = {
            "seq_id": "",
        }
        result = dg_sdk.ScanPayment.preorder_create(pre_order_type="3",
                                                    trans_amt="1.01",
                                                    goods_desc="goods_desc",
                                                    miniapp_data=json.dumps(miniapp_data))
        assert result["resp_code"] == "00000000"
